"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListDomainsForPackage = void 0;
const ListDomainsForPackageCommand_1 = require("../commands/ListDomainsForPackageCommand");
const ElasticsearchService_1 = require("../ElasticsearchService");
const ElasticsearchServiceClient_1 = require("../ElasticsearchServiceClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListDomainsForPackageCommand_1.ListDomainsForPackageCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.listDomainsForPackage(input, ...args);
};
async function* paginateListDomainsForPackage(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.NextToken = token;
        input["MaxResults"] = config.pageSize;
        if (config.client instanceof ElasticsearchService_1.ElasticsearchService) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof ElasticsearchServiceClient_1.ElasticsearchServiceClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected ElasticsearchService | ElasticsearchServiceClient");
        }
        yield page;
        token = page.NextToken;
        hasNext = !!token;
    }
    return undefined;
}
exports.paginateListDomainsForPackage = paginateListDomainsForPackage;
